@matheusbsbs / matheus-bagliano / commits / 34597c1f5a
Fork 0

hash binary sha1 into patch id

Since commit 2f82f760 (Take binary diffs into account for "git rebase"), binary files are included in patch ID computation. Binary files are diffed using the text diff algorithm, however, which has a huge impact on performance. The following tests performance for a 50000 line file marked as binary in .gitattributes. $ git format-patch --stdout --ignore-if-in-upstream master real 0m0.367s user 0m0.354s sys 0m0.010s Instead of diffing the binary files, hash the pre- and post-image sha1, which is just as unique. As a result, performance is much improved. $ git format-patch --stdout --ignore-if-in-upstream master real 0m0.016s user 0m0.015s sys 0m0.001s Signed-off-by: Clemens Buchacher <drizzd@aon.at> Signed-off-by: Junio C Hamano <gitster@pobox.com>

Clemens Buchacher committed Aug 15, 2010 at 09:20 UTC 34597c1f5a77c710dae33092cb8a7cb01c6b21c1
1 file changed +7
diff.c
+7
@@ -3758,6 +3758,13 @@ static int diff_get_patch_id(struct diff_options *options, unsigned char *sha1)
3758 len2, p->two->path);
3759 git_SHA1_Update(&ctx, buffer, len1);
3760
3761 + if (diff_filespec_is_binary(p->one) ||
3762 + diff_filespec_is_binary(p->two)) {
3763 + git_SHA1_Update(&ctx, sha1_to_hex(p->one->sha1), 40);
3764 + git_SHA1_Update(&ctx, sha1_to_hex(p->two->sha1), 40);
3765 + continue;
3766 + }
3767 +
3768 xpp.flags = 0;
3769 xecfg.ctxlen = 3;
3770 xecfg.flags = XDL_EMIT_FUNCNAMES;